Financial Models 
================ 
 
This section includes planned financial models. Contributions are welcome! 
 
- Capital Asset Pricing Model (CAPM) 
- Arbitrage Pricing Theory (APT) 
- Black-Scholes Option Pricing Model 
- Bond Valuation Models 
- Credit Risk Models (e.g., Merton Model) 
- Portfolio Optimization Models (e.g., Markowitz Model) 
